import { jsx as _jsx } from "react/jsx-runtime";
import { usePlotContext } from '../../contexts/plotContext';
import { getInnerOffset } from '../../utils/axis';
import LinearAxis from './LinearAxis';
import LogAxis from './LogAxis';
function parallelPosition(position) {
    switch (position) {
        case 'bottom': {
            return 'top';
        }
        case 'top': {
            return 'bottom';
        }
        case 'left': {
            return 'right';
        }
        case 'right': {
            return 'left';
        }
        default: {
            throw new Error(`Unknown position ${position}`);
        }
    }
}
export function ParallelAxis(props) {
    const { id, hidden = false, primaryTickLength = 5, secondaryTickLength = 3, tickPosition = 'outer', hiddenLine = false, hiddenTicks = false, ...otherProps } = props;
    const { axisContext, plotWidth, plotHeight } = usePlotContext();
    const innerOffset = getInnerOffset(hidden, hiddenTicks, tickPosition, primaryTickLength);
    // Don't display axis if parent id not in context
    const parentAxis = axisContext[id];
    if (!parentAxis)
        return null;
    // Get position opposite to parent axis
    const position = parallelPosition(parentAxis.position);
    // Renders according to position and scale
    const { type, scale, tickLabelFormat } = parentAxis;
    const childProps = {
        plotWidth,
        plotHeight,
        position,
        tickLabelFormat,
        displayPrimaryGridLines: false,
        hidden,
        primaryTickLength,
        tickPosition,
        hiddenLine,
        hiddenTicks,
        innerOffset,
        secondaryTickLength,
        ...otherProps,
    };
    if (type === 'linear') {
        return (_jsx(LinearAxis, { ...childProps, scale: scale }, void 0));
    }
    else {
        return (_jsx(LogAxis, { ...childProps, scale: scale }, void 0));
    }
}
//# sourceMappingURL=ParallelAxis.js.map