import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
import { extent } from 'd3-array';
import { useEffect, useMemo } from 'react';
import { useLegend } from '../contexts/legendContext';
import { usePlotContext, usePlotDispatchContext, } from '../contexts/plotContext';
import { functionalLabel, functionalShape, functionalStyle, useId, validateAxis, } from '../utils';
import ErrorBars from './ErrorBars';
import { markersComps } from './Markers';
export function ScatterSeries(props) {
    var _a;
    // Update plot context with data description
    const dispatch = usePlotDispatchContext();
    const { colorScaler } = usePlotContext();
    const [, legendDispatch] = useLegend();
    const id = useId(props.id, 'series');
    const { xAxis = 'x', yAxis = 'y', data, label, hidden, displayErrorBars = false, ...otherProps } = props;
    useEffect(() => {
        var _a, _b;
        if (!hidden) {
            legendDispatch({
                type: 'ADD_LEGEND_LABEL',
                payload: {
                    id,
                    label,
                    colorLine: 'white',
                    shape: {
                        color: ((_b = (_a = otherProps.markerStyle) === null || _a === void 0 ? void 0 : _a.fill) === null || _b === void 0 ? void 0 : _b.toString()) || colorScaler(id),
                        figure: 'circle',
                        hidden: false,
                    },
                },
            });
        }
        return () => legendDispatch({ type: 'REMOVE_LEGEND_LABEL', payload: { id } });
    }, [
        colorScaler,
        hidden,
        id,
        label,
        legendDispatch,
        otherProps.markerShape,
        (_a = otherProps.markerStyle) === null || _a === void 0 ? void 0 : _a.fill,
    ]);
    useEffect(() => {
        const [xMin, xMax] = extent(data, (d) => d.x);
        const [yMin, yMax] = extent(data, (d) => d.y);
        const x = { min: xMin, max: xMax, axisId: xAxis };
        const y = { min: yMin, max: yMax, axisId: yAxis };
        dispatch({ type: 'newData', payload: { id, x, y, label, data } });
        // Delete information on unmount
        return () => dispatch({ type: 'removeData', payload: { id } });
    }, [dispatch, id, data, xAxis, yAxis, label]);
    if (hidden)
        return null;
    // Render stateless plot component
    const inheritedProps = { data, xAxis, yAxis };
    const errorBarsProps = {
        hidden: !displayErrorBars,
        style: props.errorBarsStyle,
        capStyle: props.errorBarsCapStyle,
        capSize: props.errorBarsCapSize,
    };
    return (_jsxs("g", { children: [_jsx(ErrorBars, { ...inheritedProps, ...errorBarsProps }, void 0), _jsx(ScatterSeriesRender, { ...otherProps, ...inheritedProps, id: id }, void 0)] }, void 0));
}
function ScatterSeriesRender({ id, data, xAxis, yAxis, markerShape = 'circle', markerSize = 8, markerStyle = {}, pointLabel = '', pointLabelStyle = {}, }) {
    // Get scales from context
    const { axisContext, colorScaler } = usePlotContext();
    const [xScale, yScale] = validateAxis(axisContext, xAxis, yAxis);
    // calculates the path to display
    const markers = useMemo(() => {
        if (xScale === undefined || yScale === undefined) {
            return null;
        }
        const color = colorScaler(id);
        const defaultColor = { fill: color, stroke: color };
        const markers = data.map((point, i) => {
            const style = functionalStyle(defaultColor, markerStyle, point, i, data);
            // Show marker
            const Marker = markersComps[functionalShape(markerShape, point, i, data)];
            const label = functionalLabel(pointLabel, point, i, data);
            const labelStyle = functionalStyle({}, pointLabelStyle, point, i, data);
            return (_jsxs("g", { transform: `translate(${xScale(point.x)}, ${yScale(point.y)})`, children: [_jsx(Marker, { size: markerSize, style: { stroke: style.fill, ...style } }, void 0), label ? _jsx("text", { style: labelStyle, children: label }, void 0) : null] }, `markers-${i}`));
        });
        return markers;
    }, [
        xScale,
        yScale,
        colorScaler,
        id,
        data,
        markerStyle,
        markerShape,
        pointLabel,
        pointLabelStyle,
        markerSize,
    ]);
    if (!markers)
        return null;
    return _jsx("g", { className: "markers", children: markers }, void 0);
}
//# sourceMappingURL=ScatterSeries.js.map