import { CSSProperties } from 'react';
import { PlotAxisContext } from './contexts/plotContext';
import type { CSSFuncProps, LabelFuncProps, SeriesPointError, Shape, ShapeFuncProps } from './types';
/**
 * Creates autoincremental values, generally for series.
 */
export declare function getNextId(): number;
export declare function useId(id: string | undefined, prefix: string): string;
/**
 * Validates that two positions are not orthogonal between them
 */
export declare function validatePosition(currPosition: string, position: string, id: string): void;
/**
 * Validates that two axes are orthogonal between them
 */
export declare function validateAxis(axisContext: Record<string, PlotAxisContext>, xKey: string, yKey: string): (import("d3-scale").ScaleLinear<number, number, never> | import("d3-scale").ScaleTime<number, number, never>)[];
/**
 * Checks the style added to a component and if is a function, gets the resulting value
 */
export declare function functionalStyle<T>(defaultStyle: CSSProperties, elementStyle: CSSFuncProps<T>, point: T, index?: number, data?: T[]): CSSProperties;
/**
 * Checks the marker added to a component and if is a function, gets the resulting value
 */
export declare function functionalShape<T>(elementStyle: ShapeFuncProps<T>, point: T, index?: number, data?: T[]): Shape;
/**
 * Checks the label added to a component and if is a function, gets the resulting value
 */
export declare function functionalLabel<T>(elementStyle: LabelFuncProps<T>, point: T, index?: number, data?: T[]): string;
/**
 * validate series point Error
 */
export declare function validateSeriesPointError(error: SeriesPointError): SeriesPointError;
export declare function closestPoint<T, R>(data: T[], value: R, distanceFun: (a: T, b: R) => number): T;
export declare function dataConvertDate(data: {
    x: number | Date;
    y: number | Date;
}[]): {
    x: number;
    y: number;
}[];
export declare function toNumber(value: number | Date): number;
