"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.toNumber = exports.dataConvertDate = exports.closestPoint = exports.validateSeriesPointError = exports.functionalLabel = exports.functionalShape = exports.functionalStyle = exports.validateAxis = exports.validatePosition = exports.useId = exports.getNextId = void 0;
const react_1 = require("react");
let currentValue = 1;
/**
 * Creates autoincremental values, generally for series.
 */
function getNextId() {
    return ++currentValue;
}
exports.getNextId = getNextId;
function useId(id, prefix) {
    return (0, react_1.useMemo)(() => {
        if (id)
            return id;
        return `${prefix}-${getNextId()}`;
    }, [id, prefix]);
}
exports.useId = useId;
const horizontal = ['top', 'bottom'];
const vertical = ['left', 'right'];
/**
 * Validates that two positions are not orthogonal between them
 */
function validatePosition(currPosition, position, id) {
    const error = (horizontal.includes(currPosition) && !horizontal.includes(position)) ||
        (vertical.includes(currPosition) && !vertical.includes(position));
    if (error) {
        throw new Error(`The positions are ortogonal for ${id}`);
    }
}
exports.validatePosition = validatePosition;
/**
 * Validates that two axes are orthogonal between them
 */
function validateAxis(axisContext, xKey, yKey) {
    const xAxis = axisContext[xKey];
    const yAxis = axisContext[yKey];
    if (!xAxis || !yAxis)
        return [undefined, undefined];
    if (horizontal.includes(xAxis.position)
        ? !vertical.includes(yAxis.position)
        : vertical.includes(xAxis.position)) {
        if (vertical.includes(xAxis.position) ||
            horizontal.includes(yAxis.position)) {
            throw new Error(`The axis ${xKey} should be ${horizontal.join(' ')} and ${yKey} should be ${vertical.join(' ')}`);
        }
        throw new Error(`The axis ${xKey} and ${yKey} are not orthogonal`);
    }
    return [xAxis.scale, yAxis.scale];
}
exports.validateAxis = validateAxis;
/**
 * Checks the style added to a component and if is a function, gets the resulting value
 */
function functionalStyle(defaultStyle, elementStyle, point, index, data) {
    let style = { ...defaultStyle };
    for (const key in elementStyle) {
        if (typeof elementStyle[key] === 'function') {
            style[key] = elementStyle[key](point, index, data);
        }
        else {
            style[key] = elementStyle[key];
        }
    }
    return style;
}
exports.functionalStyle = functionalStyle;
/**
 * Checks the marker added to a component and if is a function, gets the resulting value
 */
function functionalShape(elementStyle, point, index, data) {
    let shape;
    if (typeof elementStyle === 'function') {
        shape = elementStyle(point, index, data);
    }
    else {
        shape = elementStyle;
    }
    return shape;
}
exports.functionalShape = functionalShape;
/**
 * Checks the label added to a component and if is a function, gets the resulting value
 */
function functionalLabel(elementStyle, point, index, data) {
    let shape;
    if (typeof elementStyle === 'function') {
        shape = elementStyle(point, index, data);
    }
    else {
        shape = elementStyle;
    }
    return shape;
}
exports.functionalLabel = functionalLabel;
/**
 * validate series point Error
 */
function validateSeriesPointError(error) {
    if (typeof error === 'number')
        return [error, error];
    else if (Array.isArray(error) && error.length >= 2)
        return error;
    return null;
}
exports.validateSeriesPointError = validateSeriesPointError;
function closestPoint(data, value, distanceFun) {
    let closest = {
        index: 0,
        distance: Infinity,
    };
    for (let i = 0; i < data.length; i++) {
        const distance = distanceFun(data[i], value);
        if (distance < closest.distance) {
            closest.index = i;
            closest.distance = distance;
        }
    }
    return data[closest.index];
}
exports.closestPoint = closestPoint;
function dataConvertDate(data) {
    return data.map(({ x, y }) => ({ x: toNumber(x), y: toNumber(y) }));
}
exports.dataConvertDate = dataConvertDate;
function toNumber(value) {
    if (typeof value === 'number') {
        return value;
    }
    return value.getTime();
}
exports.toNumber = toNumber;
